#[repr(C)]pub struct DtMeshHeader {Show 19 fields
pub x: c_int,
pub y: c_int,
pub layer: c_int,
pub user_id: c_uint,
pub poly_count: c_int,
pub vert_count: c_int,
pub max_link_count: c_int,
pub detail_mesh_count: c_int,
pub detail_vert_count: c_int,
pub detail_tri_count: c_int,
pub bv_node_count: c_int,
pub off_mesh_con_count: c_int,
pub off_mesh_base: c_int,
pub walkable_height: c_float,
pub walkable_radius: c_float,
pub walkable_climb: c_float,
pub bmin: [c_float; 3],
pub bmax: [c_float; 3],
pub bv_quant_factor: c_float,
/* private fields */
}Fields
x: c_intTile data format version number.
y: c_intThe x-position of the tile within the dtNavMesh tile grid. (x, y, layer)
layer: c_intThe y-position of the tile within the dtNavMesh tile grid. (x, y, layer)
user_id: c_uintThe layer of the tile within the dtNavMesh tile grid. (x, y, layer)
poly_count: c_intThe user defined id of the tile.
vert_count: c_intThe number of polygons in the tile.
max_link_count: c_intThe number of vertices in the tile.
detail_mesh_count: c_intThe number of allocated links.
detail_vert_count: c_intThe number of sub-meshes in the detail mesh. The number of unique vertices in the detail mesh. (In addition to the polygon vertices.)
detail_tri_count: c_intbv_node_count: c_intThe number of triangles in the detail mesh.
off_mesh_con_count: c_intThe number of bounding volume nodes. (Zero if bounding volumes are disabled.)
off_mesh_base: c_intThe number of off-mesh connections.
walkable_height: c_floatThe index of the first polygon which is an off-mesh connection.
walkable_radius: c_floatThe height of the agents using the tile.
walkable_climb: c_floatThe radius of the agents using the tile.
bmin: [c_float; 3]The maximum climb height of the agents using the tile.
bmax: [c_float; 3]The minimum bounds of the tile’s AABB. [(x, y, z)]
bv_quant_factor: c_floatThe maximum bounds of the tile’s AABB. [(x, y, z)] The bounding volume quantization factor.
Implementations
Sourceimpl DtMeshHeader
impl DtMeshHeader
pub fn from_bytes(buffer: &[u8]) -> Result<Self, ()>